/*
 * Copyright 2014 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.gradle.language.base.internal.registry;


import org.gradle.language.base.LanguageSourceSet;
import org.gradle.model.internal.core.rule.describe.ModelRuleDescriptor;
import org.gradle.model.internal.type.ModelType;

/**
 * A registered language.
 */
public interface LanguageRegistration<U extends LanguageSourceSet> {
    /**
     * The name.
     */
    String getName();

    /**
     * The interface type of the language source set.
     */
    ModelType<U> getSourceSetType();

    /**
     * The implementation type of the language source set.
     */
    ModelType<? extends U> getSourceSetImplementationType();

    /**
     * The rule that registered this type.
     */
    ModelRuleDescriptor getRuleDescriptor();
}
